Imported from libpng-1.2.2beta5.tar
diff --git a/png.h b/png.h
index 3057fbd..8c5e555 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.2.2beta4 - March 8, 2002
  * Copyright (c) 1998-2002 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -9,7 +9,7 @@
  * Authors and maintainers:
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *  libpng versions 0.97, January 1998, through 1.2.2beta4 - March 8, 2002: Glenn
  *  See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -111,8 +111,8 @@
  * If you modify libpng you may insert additional notices immediately following
  * this sentence.
  *
  * libpng versions 1.0.7, July 1, 2000, through  1.2.2beta4, March 8, 2002, are
  * Copyright (c) 2000, 2002 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.0.6
  * with the following individuals added to the list of Contributing Authors
  *
@@ -216,13 +216,13 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    March 8, 2002
+ *    March 26, 2002
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.2.2beta4 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *
  *    Libpng only has three year fields.  One is a 2-byte unsigned integer
@@ -278,7 +278,7 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.2.2beta4"
+#define PNG_LIBPNG_VER_STRING "1.2.2beta5"
 
 #define PNG_LIBPNG_VER_SONUM   0
 #define PNG_LIBPNG_VER_DLLNUM  %DLLNUM%
@@ -290,7 +290,7 @@
 /* This should match the numeric part of the final component of
  * PNG_LIBPNG_VER_STRING, omitting any leading zero: */
 
-#define PNG_LIBPNG_VER_BUILD  4
+#define PNG_LIBPNG_VER_BUILD  5
 
 #define PNG_LIBPNG_BUILD_ALPHA    1
 #define PNG_LIBPNG_BUILD_BETA     2
@@ -1257,10 +1257,10 @@
 };
 
 
-/* This prevents a compiler error in png_get_copyright() in png.c if png.c
-   and png.h are both at version 1.2.2beta4
+/* This prevents a compiler error in png.c if png.c and png.h are both at
+   version 1.2.2beta5
  */
-typedef png_structp version_1_2_2beta4;
+typedef png_structp version_1_2_2beta5;
 
 typedef png_struct FAR * FAR * png_structpp;
 
@@ -2374,6 +2374,7 @@
 #endif /* PNG_1_0_X */
 #endif /* PNG_ASSEMBLER_CODE_SUPPORTED */
 
+#if !defined(PNG_1_0_X)
 /* png.c, pnggccrd.c, or pngvcrd.c */
 extern PNG_EXPORT(int,png_mmx_support) PNGARG((void));
 
@@ -2383,11 +2384,12 @@
 extern PNG_EXPORT(void,png_set_strip_error_numbers) PNGARG((png_structp
    png_ptr, png_uint_32 strip_mode));
 #endif
+#endif /* PNG_1_0_X */
 
 /* Maintainer: Put new public prototypes here ^, in libpng.3, and project defs */
 
 #define PNG_HEADER_VERSION_STRING \
-   " libpng version 1.2.2beta4 - March 8, 2002 (header)\n"
+   " libpng version 1.2.2beta5 - March 26, 2002 (header)\n"
 
 #ifdef PNG_READ_COMPOSITE_NODIV_SUPPORTED
 /* With these routines we avoid an integer divide, which will be slower on
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.2.2beta4 - March 8, 2002
+ * libpng version 1.2.2beta5 - March 26, 2002
  * Copyright (c) 1998-2002 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -9,7 +9,7 @@
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *  libpng versions 0.97, January 1998, through 1.2.2beta4 - March 8, 2002: Glenn
+ *  libpng versions 0.97, January 1998, through 1.2.2beta5 - March 26, 2002: Glenn
  *  See also "Contributing Authors", below.
  *
@@ -111,8 +111,8 @@
  * this sentence.
  *
- * libpng versions 1.0.7, July 1, 2000, through  1.2.2beta4, March 8, 2002, are
- * Copyright (c) 2000, 2002 Glenn Randers-Pehrson, and are
+ * libpng versions 1.0.7, July 1, 2000, through 1.2.2beta5, March 26, 2002, are
+ * Copyright (c) 2000-2001 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.0.6
  * with the following individuals added to the list of Contributing Authors
@@ -216,13 +216,13 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.2.2beta4 are Y2K compliant.  It is my belief that earlier
+ *    upward through 1.2.2beta5 are Y2K compliant.  It is my belief that earlier
  *    versions were also Y2K compliant.
  *